SystemOrganization addCategory: #'SeasideAsync-Platform'!
SystemOrganization addCategory: #'SeasideAsync-Tests'!
SystemOrganization addCategory: #'SeasideAsync-Rendering'!
SystemOrganization addCategory: #'SeasideAsync-Widgets'!

!WAStandardScripts methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:54'!
ajax
	^ '

function liveUpdater(uriFunc, ret)
{
	var request = false;

	function xmlUpdater()
	{
		return sendHttpCallback(uriFunc(), ret);
	}
	return xmlUpdater;

	//	Build and send HTTP request to Seaside

	function sendHttpCallback(uri, ret, respFunc)
	{
		if (request && request.readyState < 4)
			request.abort();
		request = newHttpRequest();
		if (!!request)
			return ret;
		if (!!respFunc)
			respFunc = processRequestChange;
		request.onreadystatechange = respFunc;
		// Resolve xml entity before issuing the request
		var uri = addParameter(uri, "timestamp", (new Date()).getTime().toString());
		var regex = new RegExp("&amp;", "g");
		uri = uri.replace(regex,"&");
		request.open("GET", uri, true);
		request.send(null);
		return ret;
	}

	//	Parse HTTP response from the Seaside live callbacks as XML and update the document

	function processRequestChange()
	{
		if (request.readyState == 4) {
			var doc = request.responseXML;
			var replacements = [];
			var anyReplacement = false;
// alert( request.responseText);
// alert( request.status);
// alert( request.statusText);
// alert( request.getAllResponseHeaders() );	
// alert( request.responseXML.parseError.errorCode);
// alert( request.responseXML.parseError.reason);
			if (doc !!= null) {
				var elements = doc.getElementsByTagName("*");
				if (elements.length == 0) {
					// IE does not support the above, use an alternative hard-coded technique
					elements = getAllElements(doc)
				}
				// Find html elements with the id= attribute
				for ( var x = 1 ; x <= elements.length ; x++ ) {
					var elem = elements[x-1];
					if (elem.tagName == "body") {
						var body = xmlString(elem);
					}
					var attributes = elem.attributes;
					if (attributes.length > 0) {
						for ( var ax = 1 ; ax <= attributes.length ; ax++ ) {
							var attr = attributes[ax-1];
							var attrName = attr.name;
							if (attrName == "id") {
								// Find the html element in the document that has a matching id and replace it
								var docElement = document.getElementById(attr.value);
								if (docElement) {
									if (!!includes(replacements,elem)) {
										// HTML is only updated with the parent at highest level
										// Resolve IE and Opera issue where <br></br> skips two lines
										var regex = new RegExp("<br></br>", "g");
										var replacement = xmlString(elem).replace(regex,"<br/>");
										try {
											docElement.innerHTML = replacement;
											anyReplacement = true;
											replacements[replacements.length] = attr.value;
										} catch (e) {
											// Some browsers (like Safari) have read-only elements
											// IE does not allow form elements for innerHTML
										}
									}
								}
							}
						}
					}   
				}
				// Find html <script> elements and execute them
				for ( var x = 1 ; x <= elements.length ; x++ ) {
					var elem = elements[x-1];
					if (elem.tagName == ''script'') {
						eval(elem.childNodes[0].data);
					}
				}
			}
			if (!!anyReplacement) {
				if ( body ) {
					document.body.innerHTML = body;
				} else {
					// Most probable reason for being here : response does not have an xml content
					// For instance : an exception in the live callback
					document.body.innerHTML = request.responseText;
				}
			}
		}
	}
}
'! !

!WAStandardScripts methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:22'!
eventTracking
	^ '
function liveEventTrackerUri(event, uri)
{
	var target = (event.target) ? event.target : event.srcElement;
	uri = addParameter(uri, "timestamp", (new Date()).getTime().toString());
	uri = addParameter(uri, "eventType", event.type);
	uri = addParameter(uri, "targetValue", target.value);
	uri = addParameter(uri, "targetType", target.type);
	uri = addParameter(uri, "tagName", target.tagName);
	uri = addParameter(uri, "id", target.id);
//	Cursor position ?
	var request = newHttpRequest();
	if (!!request) return false;
	request.onreadystatechange = processEventTracker;
	// Resolve xml entity before issuing the request
	var regex = new RegExp("&amp;", "g");
	uri = uri.replace(regex,"&");
	request.open("GET", uri, true);
	request.send(null);
	return false;

	function processEventTracker()
	{
	// Response from the event tracking callback is empty
// alert( request.responseText);
// alert( request.status);
// alert( request.statusText);
// alert( request.getAllResponseHeaders() );	
// alert( request.responseXML.parseError.errorCode);
// alert( request.responseXML.parseError.reason);
	}

}
'! !

!WAStandardScripts methodsFor: '*seasideasync' stamp: 'mjl 9/11/2006 13:43'!
liveUpdate
	^ '

	var nav;
	if (navigator.userAgent.indexOf("Safari") > 0)
			nav = "Safari";
	else if (navigator.product == "Gecko")
			nav = "Gecko";
	else
			nav = "IE";

function liveUpdaterUri(uri)
{
	return liveUpdater(function() { return uri; } , false);
}

// Selection in a list box, add the selected index to the callback
function liveSelect(id, uri)
{
	function constructUri()
	{
		return addParameter(uri, "s", document.getElementById(id).selectedIndex.toString());
	}
	return liveUpdater(constructUri, false);
}

// Key stroke in an entry field, add the field value to the callback
function liveSearch(id, uri)
{
	function constructUri()
	{
		return addParameter(uri, "s", document.getElementById(id).value);
	}

   	var updater = liveUpdater(constructUri, false);
	var last = document.getElementById(id).value;
	var timeout = false;
  
	function update()
	{
		if (last !!= document.getElementById(id).value) {
			last = document.getElementById(id).value;
			updater();
		}
	}
	   
	function start() {
		if (timeout)
			window.clearTimeout(timeout);
		timeout = window.setTimeout(update, 300);
	}

	if (navigator.userAgent.indexOf("Safari") > 0)
		document.getElementById(id).addEventListener("keydown",start,false);
	else if (navigator.product == "Gecko")
		document.getElementById(id).addEventListener("keypress",start,false);
	else
		document.getElementById(id).attachEvent("onkeydown",start);
}

// Click
function liveClick(id, uri)
{
	return liveUpdaterUri(uri);
}

// Click in a checkbox
function liveCheck(id, uri)
{
	function constructUri()
	{
		return addParameter(uri, "s", document.getElementById(id).checked);
	}
	return liveUpdater(constructUri);
}

function liveScroll(id, uri)
{
   function constructUri()
   {
         return addParameter(uri, "s", document.getElementById(id).scrollTop.toString());
   }
   
   var updater = liveUpdater(constructUri, false);
   var timeout = false;

    function start() {
	   if (timeout)
	       window.clearTimeout(timeout);
	   
    	   timeout = window.setTimeout(updater, 100);
    }
   return start;
}

function timedUpdate(uri, milliSeconds)
{
	var updater = liveUpdaterUri(uri, false);
	updater();
	var again = "timedUpdate(\""+uri+"\","+milliSeconds+")";
	setTimeout(again, milliSeconds);
}
'! !

!WAStandardScripts methodsFor: '*seasideasync' stamp: 'mb 3/30/2006 13:05'!
liveUpdateUtilities
	^'
function addParameter(uri, key, value)
{
	// See http://xkr.us/articles/javascript/encode-compare/
	var separator = "?";
	if (uri.indexOf("?") >= 0)
		separator = "&";
	return uri + separator + key + "=" + encodeURIComponent(value);
}

// Function below to instantiate an XMLHttpRequest object
// Credits: http://jibbering.com/2002/4/httprequest.html
// Credits: http://www.toutjavascript.com/savoir/xmlhttprequest.php3
function newHttpRequest()
{
	var httpRequest = false;
	if(window.XMLHttpRequest)
		// Firefox, Mozilla, Safari
		httpRequest = new XMLHttpRequest();
	else if(window.ActiveXObject) 
		// Internet Explorer
		{	try {  
 				httpRequest = new ActiveXObject("Microsoft.XMLHTTP");
			} catch (e) {
  				try {
   					httpRequest = new ActiveXObject("Msxml2.XMLHTTP");
				} catch (E) {
					httpRequest = false;
 	 			}
			}
		}
	return httpRequest;
}

// Functions below to rebuild the xml string of an element
function xmlString (element) {
	var xml = "";
	for ( var x = 1 ; x <= element.childNodes.length ;  x++ ) {
		var node = element.childNodes[x-1];
		xml += outerXmlString(node);
	}
	return xml;
}
function outerXmlString (element) {
	if (!!element.tagName)
		return element.data;
	var xml = "<" + element.tagName;
	for ( var x = 1 ; x <= element.attributes.length ;  x++ ) {
		var attr = element.attributes[x-1];
		xml += " " + attr.name + "=" + ''"'' + attr.value + ''"'';
	}
	xml += ">";
	for ( var x = 1 ; x <= element.childNodes.length ;  x++ ) {
		var node = element.childNodes[x-1];
		xml += outerXmlString(node);
	}
	xml += "</" + element.tagName + ">";
	return xml;
}

// Function below to get stable equivalent of document.getElementsByTagName("*")
// Credits: http://www.siteexperts.com/tips/contents/ts16/page3.asp
function getAllElements(document)
{
	var elements = [];
	getElements(elements,document.childNodes[0])
	return elements;   
}

// Function below to recursively and deeply collect all sub-elements of an element
// Credits: http://www.siteexperts.com/tips/contents/ts16/page3.asp
function getElements(collection, element) {
	if (element == null) return;
	for ( var x = 1 ; x <= element.childNodes.length ; x++ ) {
		var node = element.childNodes[x-1];
		if (node.nodeType == 1) {
			collection[collection.length] = node[x-1];
				getElements(collection,element);
		}
	}
}

// Function below to detect if the id of any parent of an element is part of an array
function includes(collection, element) {
	var parent = element.parentNode;
	while (parent.tagName) {
		var attributes = parent.attributes;
		if (attributes.length > 0) {
			for ( var ax = 1 ; ax <= attributes.length ; ax++ ) {
				var attr = attributes[ax-1];
				var attrName = attr.name;
				if (attrName == "id") {
					for ( var x = 1 ; x <= collection.length ; x++ ) {
						if (collection[x-1] == attr.value) return true;
					}
				}
			}
		}
		parent = parent.parentNode;
	}
	return false;
}

// Get the text of the body element
function bodyText(doc)
{
	var elements = doc.getElementsByTagName("*");
	if (elements.length == 0) {
		// IE does not support the above, use an alternative hard-coded technique
		elements = getAllElements(doc)
	}
	// Find html elements with the id= attribute
	for ( var x = 1 ; x <= elements.length ; x++ ) {
		var elem = elements[x-1];
		if (elem.tagName == "BODY") {
			var body = xmlString(elem);
		}
	}
	return body;	
}

'! !

!WAHtmlRoot methodsFor: '*seasideasync' stamp: 'mb 6/14/2006 12:24'!
addMetaContentType
	self addHeadElement:
		((WAHtmlElement named: 'meta')
			attributeAt: 'http-equiv' put: 'Content-Type';
			attributeAt: 'content'  put: self contentType , '; charset=' , self charSet;
			yourself).
! !

!WAHtmlRoot methodsFor: '*seasideasync' stamp: 'mb 3/30/2006 13:08'!
contentType
	^'text/html'! !

WAHtmlRoot subclass: #WAXmlRoot
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Rendering'!

!WAXmlRoot methodsFor: 'as yet unclassified' stamp: 'mb 3/30/2006 13:06'!
contentType
	^'text/xml'! !

WAComponent subclass: #WAAutoCompleteEntryField
	instanceVariableNames: 'callback selectedObject listHeight name listWidth stringsToObjects strings prefix selectedString'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Widgets'!

!WAAutoCompleteEntryField commentStamp: '<historical>' prior: 0!
This widget is a contribution from Anthony Lander
(anthony@etherealplanet.org)!

!WAAutoCompleteEntryField methodsFor: 'accessing' stamp: 'mb 3/5/2006 22:45'!
callback: aOneArgumentBlock
	"When a selection is made, aOneArgumentBlock is evaluated with the selected object"

	callback _ aOneArgumentBlock! !

!WAAutoCompleteEntryField methodsFor: 'initialize-release' stamp: 'mb 3/5/2006 22:49'!
initialize

	super initialize.
	stringsToObjects _ Dictionary new.
	strings _ #().
	prefix _ ''.
	selectedString _ nil.
	selectedObject _ nil.
	listHeight _ 5.
	listWidth _ 30.! !

!WAAutoCompleteEntryField methodsFor: 'accessing' stamp: 'mb 3/5/2006 22:45'!
listHeight: numberOfLines
	listHeight _ numberOfLines! !

!WAAutoCompleteEntryField methodsFor: 'accessing' stamp: 'mb 3/5/2006 22:45'!
listWidth: numberOfCharacters
	listWidth _ numberOfCharacters! !

!WAAutoCompleteEntryField methodsFor: 'accessing' stamp: 'mb 3/5/2006 22:48'!
name: aString
	name _ aString! !

!WAAutoCompleteEntryField methodsFor: 'accessing' stamp: 'mb 3/5/2006 22:50'!
numberOfItems
	^stringsToObjects size! !

!WAAutoCompleteEntryField methodsFor: 'accessing' stamp: 'mb 3/5/2006 22:47'!
objects: objects strings: objectLabels

	strings _ objectLabels.
	stringsToObjects _ Dictionary new: objects size.
	objectLabels with: objects
		do: [:label :object | stringsToObjects at: label put: object].
	prefix _ ''.
	selectedString _ nil.
	selectedObject _ nil.! !

!WAAutoCompleteEntryField methodsFor: 'rendering' stamp: 'mb 3/6/2006 00:01'!
renderAutoCompleteSuggestionListOn: html 
	| labelsMatchingPrefix prefixPattern |
	html divNamed: 'D'
		with: 
			[(prefix isEmptyOrNil not and: [selectedString isNil]) 
				ifTrue: 
					[prefixPattern _ prefix asUppercase , '*'.
					labelsMatchingPrefix _ (strings 
								select: [:label | prefixPattern match: label asUppercase]) 
									asSortedCollection asArray.
					labelsMatchingPrefix isEmpty 
						ifTrue: 
							[selectedString _ ''.
							selectedObject _ nil]
						ifFalse: 
							[labelsMatchingPrefix size = 1 
								ifTrue: 
									[prefix _ selectedString _ labelsMatchingPrefix first.
									selectedObject _ stringsToObjects at: selectedString].
							html divClass: 'dropdown'
								with: 
									[html unorderedList: 
											[(labelsMatchingPrefix copyFrom: 1
												to: (labelsMatchingPrefix size min: listHeight)) do: 
														[:label | 
														html listItem: 
																[html 
																	anchorWithAction: []
																	liveAction: 
																		[:h | 
																		selectedString _ prefix _ label.
																		selectedObject _ stringsToObjects at: label.
																		callback value: selectedObject.
																		self renderAutoCompleteTextFieldOn: h]
																	text: label]]]]]]]! !

!WAAutoCompleteEntryField methodsFor: 'rendering' stamp: 'mb 3/5/2006 23:15'!
renderAutoCompleteTextFieldOn: html 
	html
		cssClass: 'autocomplete';
		divNamed: 'autocomplete'
			with: 
				[html
					cssClass: 'label';
					divNamed: 'L' with: name.
				html
					cssClass: 'input';
					divNamed: 'I'
						with: 
							[(html attributes)
								width: listWidth;
								at: #autocomplete put: 'off'.
							html 
								textInputWithValue: prefix
								callback: 
									[:v | 
									prefix _ v.
									callback value: selectedObject.
									html bold: prefix]
								liveCallback: 
									[:v :h | 
									prefix _ v.
									selectedString _ nil.
									self renderAutoCompleteSuggestionListOn: h].
							self renderAutoCompleteSuggestionListOn: html]]! !

!WAAutoCompleteEntryField methodsFor: 'rendering' stamp: 'mb 3/5/2006 22:42'!
renderContentOn: html 
	self numberOfItems > 30
		ifTrue: [self renderAutoCompleteTextFieldOn: html]
		ifFalse: [self renderSimpleDropDownOn: html]! !

!WAAutoCompleteEntryField methodsFor: 'rendering' stamp: 'mb 3/5/2006 22:43'!
renderSimpleDropDownOn: html 
	| objectsToLabels |
	objectsToLabels _ IdentityDictionary new.
	stringsToObjects 
		keysAndValuesDo: [:label :object | objectsToLabels at: object put: label].
	html
		cssClass: 'autocomplete';
		divNamed: 'autocomplete'
			with: 
				[html
					cssClass: 'label';
					divNamed: 'L' with: [html text: name].
				html
					cssClass: 'input';
					divNamed: 'I'
						with: 
							["html attributes size: listWidth."

							html 
								selectFromList: strings
								selected: strings first
								callback: 
									[:l | 
									selectedObject _ stringsToObjects at: l.
									callback value: selectedObject]]]! !

!WAAutoCompleteEntryField methodsFor: 'accessing' stamp: 'mb 3/5/2006 22:48'!
selectedObject
	^selectedObject! !

!WAAutoCompleteEntryField methodsFor: 'accessing' stamp: 'mb 3/5/2006 22:47'!
selectedObject: anObject string: aString
	prefix _ selectedString _ aString.
	selectedObject _ anObject.! !

!WAAutoCompleteEntryField methodsFor: 'css' stamp: 'mb 3/5/2006 23:21'!
style
 	^'
	.autocomplete { width: 50em;  font-family: sans-serif; font-size: 100% }
	.autocomplete .label { width: 12em; float: left; text-align: right; font-weight: bold; }
	.autocomplete .input { margin-left: 13em; width: 10em}

	.dropdown { overflow: hidden; border-width: 1px; border-style: solid; border-color: black; }
	.dropdown ul { list-style-type: none; margin: 0; padding: 0; }
	.dropdown ul li { clear: left; float: left; display: inline; width: 100%; line-height: 1.1em; }
	.dropdown ul li.selected { font-weight: bold; line-height: 1.1em; }

	.dropdown a { display: block; padding: 3px; width: 20em; background-color: #036; border-bottom: 1px solid #eee; }
	.dropdown a:link, .dropdown a:visited { color: #EEE; text-decoration: none; }
	.dropdown a:hover { background-color: #369; color: #fff; }
'! !

WAComponent subclass: #WAAutoCompleteTest
	instanceVariableNames: 'autocomplete inputValue inputValueComplete selectedClass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Tests'!

!WAAutoCompleteTest class methodsFor: 'class initialization' stamp: 'mb 6/13/2006 18:42'!
initialize
	self registerAsApplication: 'tests/async/classic/autocomplete'! !

!WAAutoCompleteTest methodsFor: 'rendering' stamp: 'mb 3/5/2006 22:51'!
children
	^Array with: autocomplete! !

!WAAutoCompleteTest methodsFor: 'initialize-release' stamp: 'mb 3/6/2006 16:45'!
initialize

	autocomplete _ (WAAutoCompleteEntryField new)
		name: 'Choose a class:';
		listHeight: 6;
		yourself! !

!WAAutoCompleteTest methodsFor: 'constants' stamp: 'mb 2/24/2006 14:48'!
namelist
	^#(Andrew Bengt Chuck Daniel Elmer Franz George Henry Isildur) ,
		#(Jefferson Jeffrey Jeremy Jerry John Josuah Kleber Lewis Mike) , 
			#( Nancy Oscar Peter Robert Roger Stephen Steven Tobias Vincent William)! !

!WAAutoCompleteTest methodsFor: 'rendering' stamp: 'mb 3/5/2006 22:54'!
renderAutoCompleteOn: html 
	| selection |
	html divNamed: #autoComplete
		with: 
			[(inputValue isEmptyOrNil not and: [inputValueComplete not]) 
				ifTrue:
					[selection _ self namelist 
								detect: [:ea | (ea copyFrom: 1 to: (inputValue size min: ea size)) asUppercase = inputValue asUppercase]
								ifNone: [nil].
					html attributes size: 3.
					html cssId: #autoCompleteSelect.
					html 
						selectFromList: self namelist
						selected: selection
						callback:
							[:v |
							inputValue _ v.
							inputValueComplete _ true]
						labels: [:ea | ea]
						liveCallback: 
							[:v :h | 
							inputValue _ v.
							inputValueComplete _ true.
							self renderTextFieldOn: h]]].
	html script: 'document.getElementById("autoComplete").style.width = document.getElementById("input").style.width'.
	! !

!WAAutoCompleteTest methodsFor: 'rendering' stamp: 'mb 3/6/2006 15:46'!
renderContentOn: html 
	| classes |


	html heading: 'AutoComplete Test (two different techniques)' level: 3; br.

	html form: [
		html defaultAction: [self inform: inputValue].
		self renderTextFieldOn: html.
		html submitButtonWithText: 'Go'].

	classes _ (Object withAllSubclasses reject: [:e | e class = Metaclass]) asArray.

	autocomplete objects: classes strings: (classes collect: [:e | e name]).
	autocomplete callback: [:class | selectedClass _ class].

	html form: [
		html text: 'You have selected: '; text: (selectedClass isNil ifTrue: ['Nothing'] ifFalse: [selectedClass name]);br;br.
		html render: autocomplete.
		html submitButtonWithAction: [] text: 'Go'].
! !

!WAAutoCompleteTest methodsFor: 'rendering' stamp: 'mb 2/24/2006 17:03'!
renderTextFieldOn: html
	html attributes addStyle: 'width: 15em'. 
	html divNamed: #input
		with: 
			[html cssId: #inputField.
			html 
				textInputWithValue: inputValue
				callback:
					[:v |
					inputValue := v. 
					inputValueComplete := true]
				liveCallback: 
					[:v :h | 
					inputValue := v.
					inputValueComplete := false.
					self renderAutoCompleteOn: h]].
	self renderAutoCompleteOn: html! !

!WAAutoCompleteTest methodsFor: 'css' stamp: 'mb 3/5/2006 23:19'!
style
	^'
#input input {
	width: 100%;
}
#autoComplete select {
	background-color: lightyellow;
	width: 100%;
}
form {
	width: 60%; 
	border: 1px solid green;
	padding: 5px;
	background-color: lightyellow;
}
'! !

WAComponent subclass: #WACanvasFocusTest
	instanceVariableNames: 'log cbValue selected'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Tests'!

!WACanvasFocusTest class methodsFor: 'as yet unclassified' stamp: 'mb 6/13/2006 18:42'!
initialize
	self registerAsApplication: 'tests/async/canvas/focuscapture'.! !

!WACanvasFocusTest methodsFor: 'initialization' stamp: 'mb 3/31/2006 09:10'!
clearLog
	log _ OrderedCollection new.
! !

!WACanvasFocusTest methodsFor: 'initialization' stamp: 'mb 3/31/2006 09:11'!
initialize
	self clearLog.
	cbValue _ false.! !

!WACanvasFocusTest methodsFor: 'rendering' stamp: 'mb 3/31/2006 09:10'!
renderContentOn: html 
	html form
		with:
			[
			html textInput
				onFocusCallback: [:event | log add: 'Entry field' -> event value];
				callback: [:v | ].
			html select
				list: #( a b c );
				onFocusCallback: [:event | log add: 'Select box' -> event value];
				selected: selected;
				callback: [:v | selected _ v ].
			html checkbox
				onClickCallback: [:event | log add: 'Checkbox' -> event value];
				value: cbValue;
				callback: [:v | cbValue := v].
			html submitButton].
	log notEmpty ifTrue: [self renderLogOn: html]! !

!WACanvasFocusTest methodsFor: 'rendering' stamp: 'mb 3/31/2006 08:44'!
rendererClass
	^ WARenderCanvas! !

!WACanvasFocusTest methodsFor: 'rendering' stamp: 'mb 3/31/2006 09:09'!
renderLogOn: html 
	html paragraph: 
		[html
			text: 'Before button was clicked, field with focus was:';
			break;
			bold: log last key;
			break;	
			text: 'At that time the field received the focus, its value was:';
			break;
			bold: log last value].
	html heading: 'Captured events' level: 5.
	log do:
			[:each | html text: each printString]
		separatedBy:
			[html break].
	self clearLog.! !

WAComponent subclass: #WACanvasLiveRequestTest
	instanceVariableNames: 'input1 input2 selection count bool country province city'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Tests'!

!WACanvasLiveRequestTest class methodsFor: 'as yet unclassified' stamp: 'mb 10/29/2005 11:39'!
canBeRoot
	^ true! !

!WACanvasLiveRequestTest class methodsFor: 'as yet unclassified' stamp: 'mb 6/13/2006 18:43'!
initialize
	self registerAsApplication: 'tests/async/canvas/livetests'.! !

!WACanvasLiveRequestTest methodsFor: 'nested' stamp: 'mb 8/16/2006 14:10'!
cityNames
	province = 'Oranjestad'
		ifTrue: [^#( 'Casibari' 'Bubali')	].
	province = 'Santa Cruz'
		ifTrue: [^#( 'Arikok' 'Yamonta')	].
	province = 'Buenos Aires'
		ifTrue: [^#('La Plata' 'Azul')].
	province = 'Cordoba'
		ifTrue: [^#('Alta Gracia' 'La Falda ')].
	^#()


! !

!WACanvasLiveRequestTest methodsFor: 'nested' stamp: 'mb 8/16/2006 14:10'!
city: anObject
	city := anObject.
! !

!WACanvasLiveRequestTest methodsFor: 'nested' stamp: 'mb 8/16/2006 14:11'!
country: anObject
	country := anObject. 
	self province: self provinceNames first. 
! !

!WACanvasLiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 8/16/2006 14:11'!
initialize
	count _ 0.
	bool _ false.
	input1 _ String new.
	input2 _ String new.
	self country: 'Argentina'.

! !

!WACanvasLiveRequestTest methodsFor: 'nested' stamp: 'mb 8/16/2006 14:12'!
provinceNames
	country = 'Aruba'
		ifTrue: [^#('Oranjestad' 'Santa Cruz')].
	country = 'Argentina'
		ifTrue: [^#( 'Buenos Aires' 'Cordoba')].
	^#()


! !

!WACanvasLiveRequestTest methodsFor: 'nested' stamp: 'mb 8/16/2006 14:12'!
province: anObject
	province _ anObject.
	self city: self cityNames first.

! !

!WACanvasLiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 1/6/2006 10:42'!
renderAnchorOn: html

	html anchor
		callback: [self error: 'Should not come here'];
		liveCallback:
			[:h | 
			h span id: 'timestamp'; with: TimeStamp now.
			h span id: 'time'; with: Time now];
		text: 'Show time'.
	html space.
	html span id: 'timestamp'; with: ''.
! !

!WACanvasLiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 11/20/2005 16:41'!
renderCheckBoxOn: html

	html form:
		[html checkbox
				value: bool; 
				callback: [:v | bool _ v];
				liveCallback: 
					[:item :h |
					bool _ item.
					"Update multiple areas of the document using one live callback"
					h span id: 'checkbox'; with: (bool ifTrue: ['checked'] ifFalse: ['unchecked']).
					h span id: 'chk'; with: (bool ifTrue: ['checked'] ifFalse: ['unchecked']).
					].
			
		html space.
		html span id: 'chk'; with: (bool ifTrue: ['checked'] ifFalse: ['unchecked']).
		].
	! !

!WACanvasLiveRequestTest methodsFor: 'nested' stamp: 'mb 8/16/2006 14:15'!
renderCitiesOn: html

	html span id: 'citySelector'; with:
		[(html select)
			list: self cityNames;
			selected: city;
			callback:[:f | city _ f ];						
			labels: [:ea |  ea ]]		
! !

!WACanvasLiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 8/16/2006 14:07'!
renderContentOn: html

	self renderWarningOn: html.
	
	html table:
		[html tableRow:
			[html tableData:
				[self renderInput1On: html.
				self renderInput2On: html.
				self renderListOn: html.
				self renderCheckBoxOn: html.
				self renderAnchorOn: html].
			html tableData:
				[html heading: 'Forward' level: 3.
				html div id: 'forward'; with: ''.
				html heading: 'Backward' level: 3.
				html div id: 'backward'; with: ''.
				html heading: 'Selection' level: 3.
				html span id: 'selection'; with: ''.
				html heading: 'Checkbox' level: 3.
				html span id: 'checkbox'; with: ''.
				html heading: 'Time' level: 3.
				html span id: 'time'; with: ''].
			]
		].
	html heading: 'Nested live callbacks' level: 3.
	self renderCountriesOn: html.


	self renderWarningOn: html.! !

!WACanvasLiveRequestTest methodsFor: 'nested' stamp: 'mb 8/16/2006 14:09'!
renderCountriesOn: html
	(html select)
		list: #( 'Argentina' 'Aruba' );
		selected: country;
		callback: [:f | country _ f]; 
		labels: [:ea |  ea ];
		liveCallback: 
			[:anObject :h | 
			country _ anObject. 
			province _ self provinceNames first. 
			city _ self cityNames first.
			self renderProvincesOn: h].

	self renderProvincesOn: html.
! !

!WACanvasLiveRequestTest methodsFor: 'as yet unclassified' stamp: 'dwj 6/9/2005 15:59'!
rendererClass
	^ WARenderCanvas! !

!WACanvasLiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 11/20/2005 16:41'!
renderInput1On: html

	html form:
		[html textInput
				value: input1; 
				callback: [:v | input1 _ v];
				liveCallback: 
					[:text :h |
					input1 _ text. 
					"Update multiple areas of the document using one live callback"
					h div id: 'forward'; with:
						[h unorderedList:
							[input1 do:
								[:c | 
								h listItem:
									[h anchor 
									callback: [self inform: c displayString];
									text: c displayString]]]].
					h span id: 'fwd'; with:
						[h text: 'Value entered= ' , input1.
						h script: 'alert("javascript in a live callback ' , input1 , ' ");']
					].
		html space.
		html span id: 'fwd'; with:'Value entered= ' , input1.
		html break.
		html text: 'Above: Javascript attached= alert("Javascript in a live callback xxx ");'
		].
! !

!WACanvasLiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 9/8/2006 10:14'!
renderInput2On: html

	html form:
		[html textArea
				value: input2;
				callback: [:v | input2 _ v];
				liveCallback: 
					[:text :h |
					input2 _ text.
					h div id: 'backward'; with: 
						[h unorderedList: 
							[input2 reverse do: 
								[:c |
								h listItem: 
									[h anchor 
										callback: [self inform: c displayString];
										text: c displayString]]]].
					h span id: 'bwd'; with: 'Value entered= ' , input2
					].
		html space.
		html span id: 'bwd'; with: 'Value entered= ' , input2
		].
! !

!WACanvasLiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 11/20/2005 16:42'!
renderListOn: html

	html form:
		[html select 
				list: #(a b c); 
				selected: selection; 
				labels: [:ea | ea displayString];
				callback: [:v | selection _ v];
				liveCallback:
					[:item :h |
					selection _ item. 
					"Update multiple areas of the document using one live callback"
					h span id: 'selection'; with: selection.
					h span id: 'sel'; with: 'Value selected= ' , selection displayString
					].
		html space.
		html span id: 'sel'; with: 'Value selected= ' , selection displayString
		].
! !

!WACanvasLiveRequestTest methodsFor: 'nested' stamp: 'mb 8/16/2006 14:14'!
renderProvincesOn: html

	html span id: 'provinceSelector'; with:
		[(html select)
			list:  self provinceNames;
			selected: province;
			callback: [:f | province _ f]; 
			labels: [:ea |  ea ];
			liveCallback: 
				[:anObject :h | 
				province _ anObject. 
				city _ self cityNames first.
				self renderCitiesOn: h]].
	self renderCitiesOn: html.


! !

!WACanvasLiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 1/6/2006 11:38'!
renderWarningOn: html 
	"The #insert: method was not available in 2.6a1"
	(html respondsTo: #insert:) ifFalse:
		[html heading: 'Warning : Canvas rendering is unfinished in this release' level: 2]   ! !

WAComponent subclass: #WACanvasPeriodicLiveRequestTest
	instanceVariableNames: 'log'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Tests'!

!WACanvasPeriodicLiveRequestTest class methodsFor: 'class initialization' stamp: 'mb 6/13/2006 18:43'!
initialize
	self registerAsApplication: 'tests/async/canvas/periodictests'.! !

!WACanvasPeriodicLiveRequestTest methodsFor: 'rendering' stamp: 'mb 3/31/2006 08:42'!
renderContentOn: html
	| liveUpdateBlock |
	liveUpdateBlock _ [ :event :h |
		h text: Time now printString].

	html table with: [
		html tableRow with: [
			html tableData with: 'Current Time in default div:'.
			html tableData with: [
				" Anonymous div. "
				html div
					refreshWith: liveUpdateBlock every: 3 seconds.
			]
		].
		html tableRow with: [
			html tableData with: 'Current Time in default span:'.
			html tableData with: [		
				" Anonymous span.  "
				html span
					refreshWith: liveUpdateBlock every: 5 seconds.
			]
		].
		html tableRow with: [
			html tableData with: 'Current Time in named div:'.
			html tableData with: [
				" Named div "
				html div
					id: 'livediv';
					refreshWith: liveUpdateBlock every: 1 seconds.
			]
		].
		html tableRow with: [
			html tableData with: 'Current Time in named span:'.
			html tableData with: [
				" Named span "
				html span
					id: 'livespan';
					refreshWith: liveUpdateBlock every: 2 seconds.
			]
		]
	]! !

!WACanvasPeriodicLiveRequestTest methodsFor: 'rendering' stamp: 'mb 3/16/2006 08:48'!
rendererClass
	^ WARenderCanvas! !

WAComponent subclass: #WAFocusTest
	instanceVariableNames: 'log cbValue selected'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Tests'!

!WAFocusTest class methodsFor: 'as yet unclassified' stamp: 'mb 6/13/2006 18:45'!
initialize
	self registerAsApplication: 'tests/async/classic/focuscapture'! !

!WAFocusTest methodsFor: 'as yet unclassified' stamp: 'mb 3/31/2006 09:05'!
clearLog
	log _ OrderedCollection new.! !

!WAFocusTest methodsFor: 'as yet unclassified' stamp: 'mb 3/31/2006 09:05'!
initialize
	self clearLog.
	cbValue _ false.! !

!WAFocusTest methodsFor: 'as yet unclassified' stamp: 'mb 3/31/2006 09:08'!
renderContentOn: html 
	html form: 
			[html onFocusCallback: [:event | log add: 'Entry field' -> event value].
			html textInputWithCallback: [:v | ].
			html onFocusCallback: [:event | log add: 'Select box' -> event value].
			html selectFromList: #( a b c )
				selected: selected
				callback: [:v | selected _ v ].
			html onClickCallback: [:event | log add: 'Checkbox' -> event value].
			html checkboxWithValue: cbValue callback: [:v | cbValue := v].
			html submitButton].

	log notEmpty ifTrue: [self renderLogOn: html]! !

!WAFocusTest methodsFor: 'as yet unclassified' stamp: 'mb 3/31/2006 09:09'!
renderLogOn: html 
	html paragraph: 
		[html
			text: 'Before button was clicked, field with focus was:';
			break;
			bold: log last key;
			break;	
			text: 'At that time the field received the focus, its value was:';
			break;
			bold: log last value].
	html heading: 'Captured events' level: 5.
	log do:
			[:each | html text: each printString]
		separatedBy:
			[html break].
	self clearLog.! !

WAComponent subclass: #WALiveRequestTest
	instanceVariableNames: 'input1 input2 input3 date selection count bool country province city'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Tests'!

!WALiveRequestTest class methodsFor: 'as yet unclassified' stamp: 'mb 10/29/2005 11:39'!
canBeRoot
	^ true! !

!WALiveRequestTest class methodsFor: 'as yet unclassified' stamp: 'mb 6/13/2006 18:45'!
initialize
	self registerAsApplication: 'tests/async/classic/livetests'.! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 10/30/2005 18:48'!
cityNames
	province = 'Oranjestad'
		ifTrue: [^#( 'Casibari' 'Bubali')	].
	province = 'Santa Cruz'
		ifTrue: [^#( 'Arikok' 'Yamonta')	].
	province = 'Buenos Aires'
		ifTrue: [^#('La Plata' 'Azul')].
	province = 'Cordoba'
		ifTrue: [^#('Alta Gracia' 'La Falda ')].
	^#()


! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 10/30/2005 18:46'!
city: anObject
	city := anObject.
! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 10/30/2005 18:48'!
country: anObject
	country := anObject. 
	self province: self provinceNames first. 
! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 3/16/2006 08:40'!
initialize
	count _ 0.
	bool  _ false.
	input1 _ String new.
	input2 _ String new.
	input3 _ 42.
	date _ Date today.
	self country: 'Argentina'.



! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 10/30/2005 18:48'!
provinceNames
	country = 'Aruba'
		ifTrue: [^#('Oranjestad' 'Santa Cruz')].
	country = 'Argentina'
		ifTrue: [^#( 'Buenos Aires' 'Cordoba')].
	^#()


! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 11/20/2005 16:43'!
province: anObject
	province _ anObject.
	self city: self cityNames first.

! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 3/30/2006 12:48'!
renderAnchorOn: html

	html anchorWithAction: 
				["The live callback disables the regular callback"
				self error: 'Should not come here, please debug me !!']
			liveAction:
				[:h | 
				h spanNamed: 'timestamp' with: TimeStamp now.
				h spanNamed: 'time' with: Time now]
			text: 'Show time'.
	html space.
	html spanNamed: 'timestamp' with: ''.
! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 11/20/2005 16:43'!
renderCheckBoxOn: html
	
	html form:
		[html checkboxWithValue: bool 
				callback: [:v | bool _ v ] 
				liveCallback: 
					[:item :h |
					bool _ item.
					"Update multiple areas of the document using one live callback"
					h spanNamed: 'checkbox' with: (bool ifTrue: ['checked'] ifFalse: ['unchecked']).
					h spanNamed: 'chk' with: (bool ifTrue: ['checked'] ifFalse: ['unchecked']).
					].
		html space.
		html spanNamed: 'chk' with: (bool ifTrue: ['checked'] ifFalse: ['unchecked']).
		].
! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 11/20/2005 16:43'!
renderCitiesOn: html

	html spanNamed: 'citySelector' with:
		[html 
			selectFromList: self cityNames
			selected: city
			callback:[:f | city _ f ]						
			labels: [:ea |  ea ]]		
! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 4/11/2006 07:19'!
renderContentOn: html

	html table: [
		html tableRowWith:
			[self renderInput1On: html.
			self renderInput2On: html.
			self renderInput3On: html.
			self renderDateInputOn: html.
			self renderListOn: html.
			self renderCheckBoxOn: html.
			self renderAnchorOn: html.

			html break.
			html anchorWithAction: 
						[self error: 'Should not come here'] 
					liveAction: 
						[:h | h spanNamed: 'time' with: 1/0] 
					text: 'Live error'.
			html break; break.
			html scrollbarWithHeight: 100 size: 1000 liveCallback: [:n :h | h spanNamed: 'scroll' with: n]	
			] 
		with: 
			[html heading: 'Forward' level: 3.
			html divNamed: 'forward' with: ''.
			html heading: 'Backward' level: 3.
			html divNamed: 'backward' with: ''.
			html heading: 'Number' level: 3.
			html divNamed: 'number' with: ''.
			html heading: 'Date' level: 3.
			html divNamed: 'date' with: ''.
			html heading: 'Selection' level: 3.
			html spanNamed: 'selection' with: ''.
			html heading: 'Check box' level: 3.
			html spanNamed: 'checkbox' with: (bool ifTrue: ['checked'] ifFalse: ['unchecked']).
			html heading: 'Time' level: 3.
			html spanNamed: 'time' with: ''.
			html heading: 'Scrollbar' level: 3.
			html spanNamed: 'scroll' with: ''.
			]
	].

	html heading: 'Nested live callbacks' level: 3.
	self renderCountriesOn: html.

	self  renderStyle: nil on: html! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 11/20/2005 16:44'!
renderCountriesOn: html 

	html
		selectFromList: #( 'Argentina' 'Aruba' )
		selected: country
		callback: [:f | country _ f] 
		labels: [:ea |  ea ]
		liveCallback: 
			[:anObject :h | 
			country _ anObject. 
			province _ self provinceNames first. 
			city _ self cityNames first.
			self renderProvincesOn: h].

	self renderProvincesOn: html.
! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 1/23/2006 18:49'!
renderDateInputOn: html

	html form:
		[html
			dateInputWithValue: date 
			callback: [:value | date _ value]
			liveCallback:
					[:value :h |
					date _ value.
					h divNamed: 'date' with: date.
					h spanNamed: 'dat' with: 'Value entered= ' , date asString.
					].
		html space.
		html spanNamed: 'dat' with: 'Value entered= ' , date asString.
		].! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 11/20/2005 16:44'!
renderInput1On: html

	html form:
		[html textInputWithValue: input1
				callback: [:v | input1 _ v]
				liveCallback:
					[:text :h |
					input1 _ text.
					"Update multiple areas of the document using one live callback"
					h divNamed: 'forward' with:
						[h list: input1 do:
							[:c |
							h anchorWithAction: [self inform: c asString] text: c asString]].
					h spanNamed: 'fwd' with:
						[h text: 'Value entered= ' , input1.
						h script: 'alert("Javascript in a live callback ' , input1 , ' ");'].
					].
		html space.
		html spanNamed: 'fwd' with: 'Value entered= ' , input1.
		html break.
		html text: 'Above: Javascript attached= alert("javascript in a live callback xxx ");'.		
		].
! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 1/23/2006 13:28'!
renderInput2On: html

	html form:
		[html textAreaWithValue: input2 
				callback: [:v | input2 _ v]
				liveCallback:
					[:text :h |
					input2 _ text.
					"Update multiple areas of the document using one live callback"
					h divNamed: 'backward' with:
						[h list: input2 reverse do:
							[:c |
							h anchorWithAction: [self inform: c asString] text: c asString]].
					h spanNamed: 'bwd' with: 'Value entered= ' , input2.
					].
		html space.
		html spanNamed: 'bwd' with: 'Value entered= ' , input2.
		].
! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 1/23/2006 14:00'!
renderInput3On: html

	html form:
		[html textInputWithValue: input3 
				callback: [:v | input3 _ v]
				liveCallback:
					[:value :h |
					input3 _ value.
					"Update multiple areas of the document using one live callback"
					h divNamed: 'number' with: input3.
					h spanNamed: 'nbr' with: 'Value entered= ' , input3 asString.
					].
		html space.
		html spanNamed: 'nbr' with: 'Value entered= ' , input3 asString.
		].! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 4/12/2006 10:24'!
renderListOn: html

	html form:
		[html selectFromList: #(red blue green) 
				selected: selection 
				callback: [:v | selection _ v]
				labels: [:ea | ea asString]
				liveCallback:
					[:item :h |
					selection _ item.
					"Update multiple areas of the document using one live callback"
					self renderStyle: selection on: h.
					h spanNamed: 'selection' with: item.
					h spanNamed: 'sel' with: 'Value selected= ' , selection displayString.
					].
		html space.
		html spanNamed: 'sel' with: 'Value selected= ' , selection displayString.
		].
! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 11/20/2005 16:44'!
renderProvincesOn: html

	html spanNamed: 'provinceSelector' with:
		[html
			selectFromList:  self provinceNames
			selected: province
			callback: [:f | province _ f] 
			labels: [:ea |  ea ]
			liveCallback: 
				[:anObject :h | 
				province _ anObject. 
				city _ self cityNames first.
				self renderCitiesOn: h]].
	self renderCitiesOn: html.


! !

!WALiveRequestTest methodsFor: 'as yet unclassified' stamp: 'mb 4/11/2006 07:52'!
renderStyle: aString on: html
	| color |
	color := aString ifNil: ['red'].
	html attributes id: 'style-1'.
	html tag: 'style' do:'#sel {color:' , color , ';}'.
	html attributes id: 'style-2'.
	html tag: 'style' do: '#selection {color:' , color , ';}'.
! !

WAComponent subclass: #WAPeriodicLiveRequestTest
	instanceVariableNames: 'log'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Tests'!

!WAPeriodicLiveRequestTest class methodsFor: 'class initialization' stamp: 'mb 6/13/2006 18:44'!
initialize
	self registerAsApplication: 'tests/async/classic/periodictests'.! !

!WAPeriodicLiveRequestTest methodsFor: 'initialize' stamp: 'mb 3/16/2006 08:40'!
initialize
	log _ String new writeStream.
! !

!WAPeriodicLiveRequestTest methodsFor: 'rendering' stamp: 'mb 3/30/2006 19:05'!
renderContentOn: html

	self renderRefreshedElementsOn: html.
	self renderRefreshedLogOn: html.
! !

!WAPeriodicLiveRequestTest methodsFor: 'rendering' stamp: 'mb 3/30/2006 19:08'!
renderLogOn: html
	html withLineBreaks: log contents
			
! !

!WAPeriodicLiveRequestTest methodsFor: 'rendering' stamp: 'mb 4/7/2006 19:36'!
renderRefreshedElementsOn: html

	| liveUpdateBlock |
	liveUpdateBlock _ [ :event :h |
		log nextPutAll:
				'Timed log at ' 
				, Time now printString 
				, ' for ' , event elementId;
			cr; 
			nextPut: Character lf.
		h text: Time now printString].
	
	html table: [
		html
			tableRowWith: [html text: 'Current Time in default div:']
				with: 
					[log nextPutAll: 'Default div id=' , html peekNextId; cr; nextPut: Character lf.
					html refreshDivWith: liveUpdateBlock every: 2 seconds];
			tableRowWith: [html text: 'Current Time in named div:']
				with: 
					[log nextPutAll: 'Named div id=myLiveDiv'; cr; nextPut: Character lf.
					html refreshDivNamed: 'myLiveDiv' with: liveUpdateBlock every: 3 seconds];
			tableRowWith: [html text: 'Current Time in default span:']
				with:
					[log nextPutAll: 'Default span id=' , html peekNextId; cr; nextPut: Character lf.
					html refreshSpanWith: liveUpdateBlock every: 5 seconds].
		].
! !

!WAPeriodicLiveRequestTest methodsFor: 'rendering' stamp: 'mb 3/30/2006 19:09'!
renderRefreshedLogOn: html
	html heading: 'Refreshed log' level: 3.
	html
		divNamed: 'log'
		with: [self renderLogOn: html]
		refreshWith:
			[ :event :h | 
			h break.
			self renderLogOn: h]
	 	every: 5 seconds 
			
! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:20'!
anchorWithAction: actionBlock liveAction: liveBlock do: aString
	| uri id |
	id _ self ensureId.
	self anchorWithAction: actionBlock do: aString.
	liveBlock fixCallbackTemps.
	uri _ self urlForLiveAction: [:event :h | liveBlock value: h].
	self 
		script: 'document.getElementById('
				, id asString printString
				, ').onclick = liveUpdaterUri('
				, (self class encode: uri asString) printString
				, ')'! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'pmm 11/3/2005 00:38'!
anchorWithAction: actionBlock liveAction: liveBlock text: aString
	self anchorWithAction: actionBlock liveAction: liveBlock do: aString.! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/30/2006 16:31'!
checkboxWithValue: aBoolean callback: callbackBlock liveCallback: liveBlock 
	| uri id |
	id _ self ensureId.
	self checkboxWithValue: aBoolean callback: callbackBlock.
	uri _ self urlForLiveAction:
		[:event :h | liveBlock
			value: event valueAsBoolean
			value: h].
	self 
		script: 'document.getElementById(' 
				, id asString printString 
				, ').onclick = liveCheck(' 
				, id asString printString 
				, ',' 
				, (self class encode: uri asString) printString 
				, ')'! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:20'!
dateInputWithValue: aDate callback: aBlock liveCallback: liveBlock
	| day month year |
	aBlock fixCallbackTemps.
	
	day _ aDate dayOfMonth.
	month _ aDate monthIndex.
	year _ aDate year.
	self
		selectFromList: (1 to: 12)
		selected: month
		callback: [:v | month _ v]
		labels: [:ea | Date nameOfMonth: ea]
		liveCallback:
			[:v :h |
			month _ v.
			liveBlock
				value: (self
							makeDateWithDay: day 
							monthNumber: month 
							year: year)
				value: h].
	self space.
	(self attributes)
			at: 'size' put: 2;
			at: 'maxlength' put: 2.			
	self
		textInputWithValue: day 
		callback: [:v | day _ v]
		liveCallback:
			[:v :h |
			day _ v.
			liveBlock
				value: (self
							makeDateWithDay: day 
							monthNumber: month 
							year: year)
				value: h].
	self space.
	(self attributes)
			at: 'size' put: 4;
			at: 'maxlength' put: 4.			
	self 
		textInputWithValue: year
		callback: [:v | year _ v]
		liveCallback:
			[:v :h |
			year _ v.
			liveBlock
				value: (self
							makeDateWithDay: day 
							monthNumber: month 
							year: year)
				value: h].
	self hiddenInputWithCallback:
		[aBlock
			value: (self
						makeDateWithDay: day 
						monthNumber: month 
						year: year)]
! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 10/31/2005 08:33'!
divNamed: divName with: aBlock refreshWith: liveBlock every: aDuration

	self
		refreshElementNamed: divName
		createElementWith: #divNamed:with:
		with: aBlock
		refreshWith: liveBlock
		every: aDuration
! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:20'!
forEvent: aString callback: callback 
	| uri |
	callback fixCallbackTemps.
	uri _ self urlForLiveAction: [:event :renderer |
		callback numArgs = 0 ifTrue: [callback value].
		callback numArgs = 1 ifTrue: [callback value: event].
		callback value: event value: renderer].
	self attributes at: aString put: 
			'liveEventTrackerUri(event,' 
			, (self class encode: uri asString) printString 
			, ')'! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/30/2006 16:25'!
fromStringLiveConverterBlockFor: anObject callback: aBlock
	^ [:event :h |
	| text |
	text _ event value. 
	aBlock value: 
		( [anObject convertSeasideString: text] on: Error do: [:e | text ] )
		value: h
	]
! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 1/23/2006 18:40'!
makeDateWithDay: day monthNumber: month year: year
	^Date
		newDay: (day min: (Date daysInMonth: month forYear: year))
		monthNumber: month
		year: year! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/30/2006 13:02'!
onClickCallback: callback 
	self forEvent: 'onclick' callback: callback! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/30/2006 13:02'!
onFocusCallback: callback 
	self forEvent: 'onfocus' callback: callback! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 10/31/2005 08:35'!
refreshDivNamed: divName with: liveBlock every: aDuration

	self
		divNamed: divName
		with: []
		refreshWith: liveBlock
		every: aDuration! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/16/2006 08:56'!
refreshDivWith: liveBlock every: aDuration
	"Convenience method if you do not want/need to supply
	the css id of the refreshing div"

	self
		refreshDivNamed: self ensureId
		with: liveBlock
		every: aDuration
! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/31/2006 10:57'!
refreshElementNamed: elementName createElementWith: aSymbol with: aBlock refreshWith: liveBlock every: aDuration
	"Private method to creates an element using aSymbol that executes and displays the result 
	of liveBlock in intervals of aDuration. The interval starts at the end of execution: 
	if liveBlock is time consuming, the next execution will happen aDuration later.
	No overlapping refreshes will occur.
	See #refreshDivWith:every: and refreshSpanWith:"
	
	| uri |
	self perform: aSymbol
			with: elementName
			with: aBlock.
	uri := self urlForLiveAction:
			[ :event :h | 
			event elementId: elementName.
			h perform: aSymbol 
				with: elementName 
				with: [liveBlock value: event value: h]].
	WACurrentSession value addLoadScript:
			'timedUpdate('
				, (self class encode: uri asString) printString
				, ', ' 
				, aDuration asMilliSeconds printString
				, ')'
! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 10/31/2005 08:37'!
refreshSpanNamed: spanName with: liveBlock every: aDuration

	self
		spanNamed: spanName 
		with: [] 
		refreshWith: liveBlock 
		every: aDuration! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/16/2006 08:56'!
refreshSpanWith: liveBlock every: aDuration
	"Convenience method if you do not want/need to supply
	the css id of the refreshing span"

	self
		refreshSpanNamed: self ensureId
		with: liveBlock
		every: aDuration
! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/30/2006 16:25'!
scrollbarWithHeight: heightNumber size: sizeNumber liveCallback: liveBlock
	| id uri |
	id _ self ensureId.
	self attributeAt: 'style' 
		put: 'position: relative; left: -3px; width: 19px; overflow: auto; height: '
			, heightNumber displayString
			, 'px'.
	self div:
		[self attributeAt: 'style' put: 'width: 1px; height: ', sizeNumber displayString, 'px'.
		self div: ''].
	uri _ self urlForLiveAction:
		[:event :h | liveBlock 
			value: event value asInteger
			value: h].
	self 
		script: 'document.getElementById('
				, id asString printString
				, ').onscroll = liveScroll('
				, id asString printString
				, ', '
				, (self class encode: uri asString) printString
				, ')'! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/30/2006 16:26'!
selectFromList: aCollection selected: anObject callback: callbackBlock labels: labelsBlock liveCallback: liveBlock
	| uri id items |
	id _ self ensureId.
	items _ aCollection asArray.
	self selectFromList: items selected: anObject callback: callbackBlock labels: labelsBlock.
	uri _ self urlForLiveAction:
			[:event :h | liveBlock 
				value: (items at: event value asInteger + 1 ifAbsent: [])
				value: h].
	self 
		script: 'document.getElementById('
				, id asString printString
				, ').onchange = liveSelect('
				, id asString printString
				, ','
				, (self class encode: uri asString) printString
				, ')'
! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mbany 4/14/2005 12:34'!
selectFromList: aCollection selected: anObject callback: aBlock labels: labelBlock other: otherBlock label: aString
	| id other  |
	id _ 'id', self context advanceKey displayString.
	other _ (self context nextKey asNumber + aCollection size + 1) displayString.
	self attributes onChange: 'if(this.value == ', other printString, ') {document.getElementById(', id printString, ').style.display = "inline"; document.getElementById(', id printString, ').focus()} else {document.getElementById(', id printString, ').style.display = "none"}'.
	self
		selectFromList: (aCollection asArray copyWith: aString)
		selected: anObject
		callback: [:v | v = aString ifFalse: [aBlock value: v]]
		labels: [:ea | ea = aString ifTrue: [aString] ifFalse: [labelBlock value: ea]].
	self space.
	self cssId: id.
	self attributes style: 'display: none'.
	self textInputWithValue: nil callback: [:v | v ifNotNil: [otherBlock value: v]]! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 10/31/2005 08:34'!
spanNamed: spanName with: aBlock refreshWith: liveBlock every: aDuration

	self
		refreshElementNamed: spanName
		createElementWith: #spanNamed:with:
		with: aBlock
		refreshWith: liveBlock
		every: aDuration
! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 1/23/2006 13:35'!
textAreaWithCallback: callbackBlock liveCallback: liveBlock
	self textAreaWithValue: '' callback: callbackBlock liveCallback: liveBlock! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/6/2006 15:38'!
textAreaWithValue: value callback: callbackBlock liveCallback: liveBlock
	| uri id liveCallback |
	id _ self ensureId.
	self textAreaWithValue: value callback: callbackBlock.
	liveCallback _ self fromStringLiveConverterBlockFor: value callback: liveBlock.
	uri _ self urlForLiveAction: liveCallback.
	self 
		script: 'liveSearch('
				, id asString printString
				, ','
				, (self class encode: uri asString) printString
				, ')'.
	! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 10/30/2005 17:41'!
textInputWithCallback: callbackBlock liveCallback: liveBlock
	self textInputWithValue: '' callback: callbackBlock liveCallback: liveBlock! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/6/2006 15:38'!
textInputWithValue: value callback: callbackBlock liveCallback: liveBlock
	| uri id liveCallback |
	id _ self ensureId.
	self textInputWithValue: value callback: callbackBlock.
	liveCallback _ self fromStringLiveConverterBlockFor: value callback: liveBlock.
	uri _ self urlForLiveAction: liveCallback.
	self 
		script: 'liveSearch('
				, id asString printString
				, ','
				, (self class encode: uri asString) printString
				, ')'.
	! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/21/2006 14:08'!
urlForLiveAction: actionBlock 
	| url |
	url _ context actionUrl withParameter: (self callbacks registerLiveActionCallback: actionBlock renderer: self).
	^url asString! !

!WAHtmlRenderer methodsFor: '*seasideasync' stamp: 'mb 3/30/2006 12:57'!
urlForLiveRequest: aBlock
	| request text ts response renderer document |
	request _ ResponseContinuation currentDo: [ :cc | 
		^ WACurrentSession value 
			actionUrlForContinuation: cc ].
	text _ request at: 's' ifAbsent: [].
	ts _ request at: 'timestamp'.	"Unused, but documented like that"
	response _ WAResponse new.
	response contentType: 'text/xml; charset=utf-8'.
	renderer _ self class
		context: self context copy
		callbacks: self callbacks.
	document _ WAXmlStreamDocument new 
		stream: response stream.
	renderer context document: document.
	aBlock value: text value: renderer.
	document close.
	WACurrentSession value returnResponse: response! !

!WARenderCanvas methodsFor: '*seasideasync' stamp: 'mb 3/21/2006 14:08'!
urlForLiveAction: actionBlock 
	| url |
	url _ context actionUrl withParameter: (self callbacks registerLiveActionCallback: actionBlock renderer: self).
	^url asString! !

!WARenderCanvas methodsFor: '*seasideasync' stamp: 'mb 3/30/2006 13:03'!
urlForLiveRequest: aBlock
	| request text ts response renderer document |
	request _ ResponseContinuation currentDo: [ :cc | 
		^ WACurrentSession value 
			actionUrlForContinuation: cc ].
	text _ request at: 's' ifAbsent: [].
	ts _ request at: 'timestamp'.	"Unused, but documented like that"
	response _ WAResponse new.
	response contentType: 'text/xml; charset=utf-8'.
	renderer _ self class 
		context: self context copy
		callbacks: self callbacks.
	document _ WAXmlStreamDocument new 
		stream: response stream.
	renderer context document: document.
	aBlock value: text value: renderer.
	document close.
	WACurrentSession value returnResponse: response! !

!WARequest methodsFor: '*seasideAsync' stamp: 'mb 3/30/2006 15:52'!
includesKey: key
	^ fields includesKey: key! !

!WAAnchorTag methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:20'!
liveCallback: liveBlock
	| uri id |
	liveBlock fixCallbackTemps.
	id _ self ensureId.
	uri _ canvas urlForLiveAction: [:event :h | liveBlock value: h].
	self session 
		addLoadScript: 
			'document.getElementById('
				, id asString printString
				, ').onclick = liveClick(' 
				, id asString printString
				, ','
				, (canvas encode: uri asString) printString
				, ')'
! !

Object subclass: #WALiveEvent
	instanceVariableNames: 'type when elementTagName elementId elementValue elementType'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Rendering'!

!WALiveEvent class methodsFor: 'as yet unclassified' stamp: 'mb 3/30/2006 16:46'!
initialize
	(self respondsTo: #convertSeasideString:)
		ifFalse:
			[self error: 'This version of SeasideAsync requires Seaside 2.6b1 or better'].! !

!WALiveEvent class methodsFor: 'as yet unclassified' stamp: 'mb 3/30/2006 13:26'!
newFromRequest: aRequest
	^self new fromRequest: aRequest! !

!WALiveEvent methodsFor: 'accessing' stamp: 'mb 3/30/2006 13:31'!
elementId
	"Answer the value of elementId"

	^ elementId! !

!WALiveEvent methodsFor: 'accessing' stamp: 'mb 3/30/2006 17:19'!
elementId: id
	^ elementId _ id! !

!WALiveEvent methodsFor: 'accessing' stamp: 'mb 3/30/2006 13:31'!
elementTagName
	"Answer the value of elementTagName"

	^ elementTagName! !

!WALiveEvent methodsFor: 'accessing' stamp: 'mb 3/30/2006 19:15'!
elementType
	"Answer the value of elementType"

	^ elementType! !

!WALiveEvent methodsFor: 'accessing' stamp: 'mb 3/30/2006 13:31'!
elementValue
	"Answer the value of elementValue"

	^ elementValue! !

!WALiveEvent methodsFor: 'initialization' stamp: 'mb 3/30/2006 19:14'!
fromRequest: aRequest
	when _ aRequest at: 'timestamp'.
	(aRequest includesKey: 's') ifTrue:
		"Live callback"
		[elementValue _ aRequest at: 's'].
	(aRequest includesKey: 'eventType') ifTrue:
		"Event tracking"
		[type _ aRequest at: 'eventType'.
		elementType _ aRequest at: 'targetType'.
		elementTagName _ aRequest at: 'tagName'.
		elementId _ aRequest at: 'id'.
		elementValue _ aRequest at: 'targetValue'].
	
! !

!WALiveEvent methodsFor: 'accessing' stamp: 'mb 3/30/2006 13:31'!
type
	"Answer the value of type"

	^ type! !

!WALiveEvent methodsFor: 'services' stamp: 'mb 3/30/2006 16:29'!
value
	type = 'check' ifTrue: [^self valueAsBoolean].
	^elementValue.! !

!WALiveEvent methodsFor: 'services' stamp: 'mb 3/30/2006 16:29'!
valueAsBoolean
	^elementValue = 'true'! !

!WALiveEvent methodsFor: 'accessing' stamp: 'mb 3/30/2006 13:31'!
when
	"Answer the value of when"

	^ when! !

WAHtmlStreamDocument subclass: #WAXmlStreamDocument
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Rendering'!

!WAXmlStreamDocument class methodsFor: 'instance creation' stamp: 'mb 3/30/2006 12:55'!
new
	^ self root: self newRoot! !

!WAXmlStreamDocument class methodsFor: 'instance creation' stamp: 'mb 3/30/2006 12:54'!
newRoot
	^ self rootClass new! !

!WAXmlStreamDocument class methodsFor: 'instance creation' stamp: 'mb 3/30/2006 12:52'!
rootClass
	^WAXmlRoot! !

!WAXmlStreamDocument methodsFor: 'as yet unclassified' stamp: 'mb 8/16/2006 14:41'!
close
	self writeLoadScripts.
	super close.! !

!WAXmlStreamDocument methodsFor: 'as yet unclassified' stamp: 'mb 8/16/2006 14:38'!
writeLoadScripts
	| session attributes |
	session := WACurrentSession value.
	(session isNil or: [ session onLoadScripts isEmpty ])
		ifTrue: [ ^ self ].
	attributes := WAHtmlAttributes new.
	attributes at: 'type' put: 'text/javascript'.
	self openTag: 'script' attributes: attributes.
	session onLoadScripts
		do: [ :each | self text: each displayString ]
		separatedBy: [ self text: ';' ].
	self closeTag: 'script'.
	session clearLoadScripts! !

!WACallbackRegistry methodsFor: '*seasideasync' stamp: 'mb 3/21/2006 14:10'!
registerLiveActionCallback: aBlock renderer: aRenderer
	^self storeCallback: (WALiveActionCallback new
		block: aBlock;
		rendererClass: aRenderer class;
		callbacks: self)! !

WAActionCallback subclass: #WALiveActionCallback
	instanceVariableNames: 'rendererClass callbacks'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Rendering'!

!WALiveActionCallback commentStamp: '<historical>' prior: 0!
This idea is from Radoslav Hodnicak
(rh@4096.sk)

Apparently the way LiveUpdate is built currently(SeasideAsync-mb.23), the 
live callbacks have a different session step (_k) than the rest of the page,
i.e. a new continuation for each live callback. If you generate enough of
them, then the original page gets pushed so far back in the history that
it blows the cache. 

Rado's changes fix this problem by processing live callbacks in the same way
normal callbacks are processed, instead of treating them as separate continuations.

The changes are activated in WAHtmlRenderer and WARenderCanvas by sending
#urlForLiveAction: rather than #urlForLiveRequest: The old behavior can be
restored by sending #urlForLiveRequest: rather than #urlForLiveAction:

!

!WALiveActionCallback methodsFor: 'accessing' stamp: 'mb 3/5/2006 18:58'!
callbacks
	"Answer the value of callbacks"

	^ callbacks! !

!WALiveActionCallback methodsFor: 'accessing' stamp: 'mb 3/5/2006 18:58'!
callbacks: anObject
	"Set the value of callbacks"

	callbacks _ anObject! !

!WALiveActionCallback methodsFor: 'as yet unclassified' stamp: 'mb 3/31/2006 08:24'!
evaluateWithArgument: argument 
	| currentSession request response renderer document event |
	currentSession _ WACurrentSession value.
	request _ currentSession currentRequest.
	event _ WALiveEvent newFromRequest: request.
	response _ WAResponse new.
	response contentType: 'text/xml; charset=utf-8'.
	renderer _ self rendererClass
		context: context copy
		callbacks: self callbacks.
	document _ WAXmlStreamDocument new
		stream: response stream.
	renderer context document: document.
	block value: event value: renderer.
	document close.
	currentSession returnResponse: response! !

!WALiveActionCallback methodsFor: 'accessing' stamp: 'mb 3/21/2006 14:21'!
rendererClass
	^rendererClass
! !

!WALiveActionCallback methodsFor: 'accessing' stamp: 'mb 3/21/2006 14:06'!
rendererClass: anObject
	"Set the value of rendererClass"

	rendererClass _ anObject! !

!WAHtmlCanvas methodsFor: '*seasideasync' stamp: 'rjl 12/30/2005 16:34'!
space
	self html: '&#160;'
! !

!WAAbstractTextAreaTag methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:20'!
liveCallback: liveBlock
	| uri id |
	liveBlock fixCallbackTemps.
	id _ self ensureId.
	uri _ canvas urlForLiveAction: 
		[:event :h | liveBlock
			value: event value
			value: h].
	self session 
		addLoadScript: 
			'liveSearch('
				, id asString printString
				, ','
				, (canvas encode: uri asString) printString
				, ')'.! !

!WACheckboxTag methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:20'!
liveCallback: liveBlock
	| uri id |
	liveBlock fixCallbackTemps.
	id _ self ensureId.
	uri _ canvas urlForLiveAction: 
		[:event :h | liveBlock 
			value: event valueAsBoolean
			value: h].
	self session 
		addLoadScript: 
			'document.getElementById('
				, id asString printString
				, ').onclick = liveCheck(' 
				, id asString printString
				, ','
				, (canvas encode: uri asString) printString
				, ')'
! !

!WASelectTag methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:21'!
liveCallback: liveBlock
	| uri id |
	liveBlock fixCallbackTemps.
	id _ self ensureId.
	uri _ canvas urlForLiveAction:
		[:event :h | liveBlock
			value: (list at: event value asInteger + 1 ifAbsent: [])
			value: h].
	self session 
		addLoadScript: 
			'document.getElementById('
				, id asString printString
				, ').onchange = liveSelect('
				, id asString printString
				, ','
				, (canvas encode: uri asString) printString
				, ')'
! !

!WATagBrush methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:21'!
forEvent: aString callback: callback 
	| uri |
	callback fixCallbackTemps.
	uri _ canvas urlForLiveAction: [:event :renderer |
		callback numArgs = 0 ifTrue: [callback value].
		callback numArgs = 1 ifTrue: [callback value: event].
		callback value: event value: renderer].
	self attributes at: aString put: 
			'liveEventTrackerUri(event,' 
			, (canvas encode: uri asString) printString 
			, ')'! !

!WATagBrush methodsFor: '*seasideasync' stamp: 'mb 3/31/2006 08:54'!
onClickCallback: aBlock
	self forEvent: 'onclick' callback: aBlock ! !

!WATagBrush methodsFor: '*seasideasync' stamp: 'mb 3/31/2006 08:54'!
onFocusCallback: aBlock
	self forEvent: 'onfocus' callback: aBlock ! !

!WATagBrush methodsFor: '*seasideasync' stamp: 'mb 10/31/2006 08:21'!
refreshWith: liveBlock every: aDuration
	" I refresh myself every aDuration with aBlock.
	No overlapping executions will take place, the next refresh is only scheduled after the block finished executing "
	| uri id |
	liveBlock fixCallbackTemps.
	id _ self ensureId.
	uri := canvas urlForLiveAction:
			[ :event :renderer |
			(renderer tag: self tag)
				id: id; 
				with: [liveBlock value: event value: renderer].].
	self session
		addLoadScript: 
			'timedUpdate('
				, (canvas encode: uri asString) printString
				, ', ' 
				, aDuration asMilliSeconds printString
				, ')'
! !

PackageInfo subclass: #SeasideAsyncVWInfo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideAsync-Platform'!

!SeasideAsyncVWInfo class methodsFor: 'file-out' stamp: 'mb 11/18/2005 09:05'!
fileOutVW5
	VW5PackageExporter
		fileOutPackage: self default 
		on: (FileStream forceNewFileNamed: 'SeasideAsyncVW5.st')! !

!SeasideAsyncVWInfo methodsFor: 'as yet unclassified' stamp: 'mb 11/18/2005 13:55'!
externalName
	^ 'SeasideAsync'! !

!SeasideAsyncVWInfo methodsFor: 'as yet unclassified' stamp: 'mb 11/18/2005 09:06'!
ignoredCategories
	^ #('Platform' )! !

!SeasideAsyncVWInfo methodsFor: 'as yet unclassified' stamp: 'mb 11/18/2005 09:10'!
includesSystemCategory: aString
	^ (aString beginsWith: 'SeasideAsync-')
	 and: [(self ignoredCategories includes: (aString copyAfter: $-)) not]! !

!SeasideAsyncVWInfo methodsFor: 'as yet unclassified' stamp: 'mb 11/18/2005 13:48'!
isYourClassExtension: aString
	^ (self category: aString asLowercase matches: '*seasideasync')
		and: [(aString endsWith: 'squeak') not]! !

!SeasideAsyncVWInfo methodsFor: 'as yet unclassified' stamp: 'mb 5/30/2006 16:40'!
name
	^ 'SeasideAsync'! !

!SeasideAsyncVWInfo methodsFor: 'as yet unclassified' stamp: 'mb 1/13/2006 16:21'!
namespace
	^ 'Seaside'! !

!SeasideAsyncVWInfo methodsFor: 'as yet unclassified' stamp: 'mb 11/18/2005 09:08'!
needsNamespace
	^false! !

!SeasideAsyncVWInfo methodsFor: 'as yet unclassified' stamp: 'mb 11/18/2005 09:09'!
packageName
	^ 'SeasideAsyncVW'! !

!SeasideAsyncVWInfo methodsFor: 'as yet unclassified' stamp: 'mb 5/30/2006 16:40'!
versionString
	| ancestor |
	ancestor _ (MCPackage named: self name) workingCopy ancestry ancestors first.
	^ancestor name , '.mcz      ' , ancestor date printString, ' ', ancestor time printString ! !

!WAAbstractHtmlBuilder methodsFor: '*seasideasync' stamp: 'rjl 12/30/2005 16:34'!
space
	self html: '&#160;'
! !
WAAutoCompleteTest initialize!
WACanvasFocusTest initialize!
WACanvasLiveRequestTest initialize!
WACanvasPeriodicLiveRequestTest initialize!
WAFocusTest initialize!
WALiveRequestTest initialize!
WAPeriodicLiveRequestTest initialize!
WALiveEvent initialize!
